/*
 * linux/include/asm-arm/arch-sa100eval/irqs.h
 *
 * Copyright (C) 1996 Russell King
 */


/* 16 from foot-bridge (spares) and 16 from the IDE chip (Intel architecture) */
#define NR_IRQS 32


/*
 * These are not physical interrupts. These are logical
 * interrupts, enabled and disabled by the kernel.
 * For instance, the IRQ_PCI_ERR represents the combination
 * of a half dozen hardware irq sources, all which resolve
 * down to a fatal bus error.
 *
 * All 553 interrupts are funnel'd through FootBridge irq_in_3 (FB.11)
 *
 * These #define's seem to line up with the physical addresses, but
 * this is only for speed of irq-response. 
 */

#define IRQ_SWI 	1	/* from FB.1 */
#define IRQ_UART_DEBUG 	2 	/* from FB.2 & FB.3  future  */
#define IRQ_TIMER0	4 	/* from FB.4 */
#define IRQ_TIMER1	5 	/* from FB.5 */
#define IRQ_TIMER2	6 	/* from FB.6 */
#define IRQ_WATCHDOG	7 	/* from FB.7 */
#define IRQ_ETHER10 	8 	/* from FB.8 */
#define IRQ_ETHER100 	9 	/* from FB.9 */
#define IRQ_VIDCOMP 	10 	/* from FB.10 */
#define IRQ_EXTERN_IRQ	11	/* from FB.11: chain to IDE irq's */
#define IRQ_DMA1	12	/* future */
#define IRQ_PCI_ERR 	15 	/* from FB.[28:31] */

/* these are all on the chained irq chip */
#define IRQ_TIMER4	16 	/* from 553.0 */
#define IRQ_KEYBOARD	17 	/* from 553.1 */
/* interrupt 553.2 is the chained to 553.8-553.15 */
#define IRQ_PIC_HI	18
#define IRQ_UART2       19	/* from 553.3 */
#define IRQ_UART	20	/* from 553.4 */ 
#define IRQ_MOUSE	21 	/* from 553.5 */
#define IRQ_UART_IR	22 	/* from 553.6 */
#define IRQ_PRINTER 	23 	/* from 553.7 */
#define IRQ_RTC_ALARM 	24 	/* from 553.8 */
#define IRQ_POWERLOW	26 	/* from 553.A */
#define IRQ_VGA		27 	/* from 553.A -> 553.11 */
#define IRQ_SOUND	28 	/* from 553.12 */
#define IRQ_HARDDISK	30 	/* from 553.14 */


/* These defines handles the translation from the above FB #defines
	into physical bits for the FootBridge irq registers */
#define IRQ_SWI_MASK 		2	/* from FB.1 */
#define IRQ_UART_DEBUG_MASK 	0xC 	/* from FB.2 & FB.3  future  */
#define IRQ_TIMER0_MASK		0x10 	/* from FB.4 */
#define IRQ_TIMER1_MASK		0x20 	/* from FB.5 */
#define IRQ_TIMER2_MASK		0x40 	/* from FB.6 */
#define IRQ_WATCHDOG_MASK 	0x80 	/* from FB.7 */
#define IRQ_ETHER10_MASK 	0x100 	/* from FB.8 */
#define IRQ_ETHER100_MASK 	0x200 	/* from FB.9 */
#define IRQ_VIDCOMP_MASK 	0x400 	/* from FB.10 */
#define IRQ_EXTERN_IRQ_MASK	0x800	/* from FB.11: chain to IDE irq's */
#define IRQ_DMA1_MASK		0x30000		/* future */
#define IRQ_PCI_ERR_MASK 	0xF0000000 	/* from FB.[28:31] */

#ifndef __ASSEMBLER__

/* This array is a colletion of the *_MASK patterns
	(init in arch-arm/kernel/irq.c) */
extern int fb_irq_mask[16];

#endif

